function time_serie_histog_phase_num(phase_num)
% time_serie_histog_phase_num ++explication between 1 and 8

%+
%
%  .. _time_serie_histog_phase_num.m:
%
% =============================
% time_serie_histog_phase_num.m
% =============================
%
% ++
%
% DESCRIPTION
% ===========
%
% From :file:`occu.txt` and :file:`phase{phase_num}.txt`, time_serie_histog_phase_num plots
% for each WT ++.
%
% EXAMPLES
% ========
%
% Following line read :file:`phase1.txt` and :file:`occu.txt` and plots for each WT ++
%
% ::
%
% >> time_serie_histog_phase_num(1);
%
% SEE ALSO
% ========
%
% :ref:`lagged_correlations_eof2_eof3_1030.m`
%
% :ref:`composite_olr_phase_num.m`
%
% :ref:`composite_olr_phase.m`
%
% :ref:`time_serie_histog_phase.m`
%
% TODO
% ====
%
% improve description
%
% improve file pb
%
% use return function
%
% EVOLUTIONS
% ==========
%
% $Id$
%
%
% - fplod 2009-02-11T16:27:34Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * add try/catch on opening file for reading
%
% - fplod 2009-01-28T09:01:45Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * created from time_serie_histog_phase1.m to replace it as well as
%     time_serie_histog_phase[2-8].m
%
%-

global IRCAAM_ID;

phase_num_min=1;
phase_num_max=8;

if nargin==1
 % phase_num must be greater or equal to 1 and lower or equal to 8
 if ((phase_num < phase_num_min) || (phase_num > phase_num_max))
  disp(['phase_num_min = ', int2str(phase_num_min)]);
  disp(['phase_num_max = ', int2str(phase_num_max)]);
  error('eee : phase_num must be between phase_num_min and phase_num_max');
 end
else
  usage='usage : time_serie_histog_phase_num(phase_num)';
  disp(usage);
  error('eee : wrong arguments numbers')
end

fullfilename=[IRCAAM_ID,'phase',int2str(phase_num),'.txt'];
try
 status=load(fullfilename);
catch
 error('eee : File %s not found\n', fullfilename);
end

clear fullfilename;

phase=status;
clear status;
phase=reshape(phase,122,28,3);

%%%%%%%%%%%% FICHIER TYPE DE TEMPS
% on ouvre le fichier
fullfilename=[IRCAAM_ID,'occu.txt'];
status=load(fullfilename);
clear fullfilename;
occu=status;
clear status;

% on reorganise le fichier de type de temps (jours,annees,cluster)
y=reshape(occu,122,58,4);
clear occu;

% on selectionne les annees de 1979 a 2006
occu_type_tps(:,:,:)=y(:,30:57,:);
clear y;

% intialisation des tableaux
type_temps_compomax=zeros(80,21,4);
compteurmax=0;

% boucle sur les annees
for a=1:28;
   for b=1:122;
      % 1ere condition (laisser une marge de 10)
      if (b>11 && b<112);
%        condition 1 on est a un maximum deltas apres sont negetifs et
%             delta avant postifs
         if phase(b,a,1)==1;
            compteurmax=compteurmax+1;
            type_temps_compomax(compteurmax,1,:)=occu_type_tps(b-10,a,:);
            type_temps_compomax(compteurmax,2,:)=occu_type_tps(b-9,a,:);
            type_temps_compomax(compteurmax,3,:)=occu_type_tps(b-8,a,:);
            type_temps_compomax(compteurmax,4,:)=occu_type_tps(b-7,a,:);
            type_temps_compomax(compteurmax,5,:)=occu_type_tps(b-6,a,:);
            type_temps_compomax(compteurmax,6,:)=occu_type_tps(b-5,a,:);
            type_temps_compomax(compteurmax,7,:)=occu_type_tps(b-4,a,:);
            type_temps_compomax(compteurmax,8,:)=occu_type_tps(b-3,a,:);
            type_temps_compomax(compteurmax,9,:)=occu_type_tps(b-2,a,:);
            type_temps_compomax(compteurmax,10,:)=occu_type_tps(b-1,a,:);
            type_temps_compomax(compteurmax,11,:)=occu_type_tps(b,a,:);
            type_temps_compomax(compteurmax,12,:)=occu_type_tps(b+1,a,:);
            type_temps_compomax(compteurmax,13,:)=occu_type_tps(b+2,a,:);
            type_temps_compomax(compteurmax,14,:)=occu_type_tps(b+3,a,:);
            type_temps_compomax(compteurmax,15,:)=occu_type_tps(b+4,a,:);
            type_temps_compomax(compteurmax,16,:)=occu_type_tps(b+5,a,:);
            type_temps_compomax(compteurmax,17,:)=occu_type_tps(b+6,a,:);
            type_temps_compomax(compteurmax,18,:)=occu_type_tps(b+7,a,:);
            type_temps_compomax(compteurmax,19,:)=occu_type_tps(b+8,a,:);
            type_temps_compomax(compteurmax,20,:)=occu_type_tps(b+9,a,:);
            type_temps_compomax(compteurmax,21,:)=occu_type_tps(b+10,a,:);
         end;
      end;
   end;
end;

% on ne selectionne que la partie du tableau ou il y a des valeurs
type_temps_compomax=type_temps_compomax(1:compteurmax,:,:);

type_temps_moy=reshape(occu_type_tps,3416,4);
disp(['iii : compteurmax =', int2str(compteurmax)]);
% on fait la somme des types de temps sur toute la periode de temps
% on obtent un tableau de la forme (jours-avant-apres,cluster)

type_temps_compomax1(:,:)=sum(type_temps_compomax);
type_temps_moy=sum(type_temps_moy);

clear type_temps_compomax;

% on fait la somme => le nbre de jour avec 1 type de temps persistant
% pour chaque jour
sum_kara_max=sum((type_temps_compomax1)');

% on traduit le nbre d occurence en frequences relatives
kara_max=zeros(21,4);
kara_moy=zeros(21,4);
for a=1:21;
   for b=1:4;
      kara_max(a,b)=type_temps_compomax1(a,b)/sum_kara_max(a);
      kara_moy(b)=type_temps_moy(b)/3416;
   end;
end;

x=[-10:1:10]';
kara_diff=zeros(21,4);
for a=1:21;
    for b=1:4
       kara_diff(a,b)=kara_max(a,b)-kara_moy(b);
    end;
end;

offset=mod(phase_num-1,4)*4;
for a=1:4;
    subplot(4,4,a+offset);
    diff=kara_diff(:,a)*100;
    jour=[-10:10]';
    if a==1;
       bar(jour,diff,'r');
       c=[1 0.55 0];
       bar(jour,diff),colormap(c);
    elseif a==2;
       bar(jour,diff,'g');
    elseif a==3;
       bar(jour,diff,'b');
    else
       bar(jour,diff,'r');
    end;
    set (gca,'XTick',[-10:2:10],'XTickLabel',[-10:2:10],'fontname','Arial','fontsize',6);
    set (gca,'YTick',[-20:10:20],'YTickLabel',[-20:5:20],'fontname','Arial','fontsize',6);
    axis([-10 10 -20 20]);
    set (gca,'tickDir','out');
    if a==1;
       title('Atl low','Fontsize',8,'Fontname','Arial');
       ylabel=['Phase ' int2str(phase_num)];
       text(-20,0,ylabel);
       clear ylabel;
    elseif a==2;
       title('Atl Ridge','Fontsize',8,'Fontname','Arial');
    elseif a==3;
       title('NAO-','Fontsize',8,'Fontname','Arial');
    else
       title('Blocking','Fontsize',8,'Fontname','Arial');
    end;
end;
clear offset;
